Documentation
¶
Index ¶
- Constants
- func Config(w http.ResponseWriter, r *http.Request)
- func Cron(w http.ResponseWriter, r *http.Request)
- func MessagePairs(client *firestore.Client, ctx context.Context)
- func MessageSolo(client *firestore.Client, ctx context.Context)
- func PostDaily(client *firestore.Client, ctx context.Context)
- func TestMain(m *testing.M)
- func Webhook(w http.ResponseWriter, r *http.Request)
- type Messenger
- type Path
- type Recurser
- type UserConfig
Constants ¶
const FirestoreEmulatorHost = "FIRESTORE_EMULATOR_HOST"
Variables ¶
This section is empty.
Functions ¶
func Cron ¶
func Cron(w http.ResponseWriter, r *http.Request)
Cron makes matches for pairing, and messages those people to notify them of their match it runs once per day at 8am (it's triggered with app engine's Cron service)
Types ¶
type Messenger ¶
type Messenger struct {
Help string `json:"help"`
Subscribe string `json:"subscribe"`
Unsubscribe string `json:"unsubscribe"`
NotSubscribed string `json:"notSubscribed"`
NotConfigured string `json:"notConfigured"`
NotMatched string `json:"notMatched"`
Matched string `json:"matched"`
WriteError string `json:"writeError"`
ReadError string `json:"readError"`
}
func InitMessenger ¶
type Recurser ¶
type Recurser struct {
Id string `structs:"id" firestore:"id"`
Name string `structs:"name" firestore:"name"`
Email string `structs:"email" firestore:"email"`
IsSkippingTomorrow bool `structs:"isSkippingTomorrow" firestore:"isSkippingTomorrow"`
IsPairingTomorrow bool `structs:"isPairingTomorrow" firestore:"isPairingTomorrow"`
Config UserConfig `structs:"config" firestore:"config"`
}
type UserConfig ¶
type UserConfig struct {
Comments string `structs:"comments" firestore:"comments"`
Environment string `structs:"environment" firestore:"environment"`
Experience string `structs:"experience" firestore:"experience"`
ProblemSet string `structs:"problemSet" firestore:"problemSet"`
Topics []string `structs:"topics" firestore:"topics"`
SoloDays []string `structs:"soloDays" firestore:"soloDays"`
SoloDifficulty []string `structs:"soloDifficulty" firestore:"soloDifficulty"`
PairingDifficulty []string `structs:"pairingDifficulty" firestore:"pairingDifficulty"`
ManualQuestion bool `structs:"manualQuestion" firestore:"manualQuestion"`
}
Click to show internal directories.
Click to hide internal directories.